<h1 align="center">Amazon EKS Blueprints for CDK Python</h1>

<p align="center">
<img alt="GitHub Workflow Status (with branch)" src="https://img.shields.io/github/actions/workflow/status/leunguu/cdk-eks-blueprint/test.yml?branch=main">
<img alt="GitHub" src="https://img.shields.io/github/license/leunguu/cdk-eks-blueprint">
<img alt="PyPI" src="https://img.shields.io/pypi/v/cdk-eks-blueprint">
<img alt="PRs Welcome" src=https://img.shields.io/badge/PRs-welcome-brightgreen.svg>
</p>

Welcome to Amazon EKS Blueprints for CDK Python!

The purpose of this project is to make things easy when developers build eks cluster with CDK Python.

